==> nextcloud-27.1.11.tgz: nextcloud/apps/weather_status/l10n/is.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Óþekkt vistfang",
    "No result." : "Engar niðurstöður.",
    "Malformed JSON data." : "Gölluð JSON-gögn.",
    "Error" : "Villa",
    "Weather status" : "Veðurlýsing",
    "Weather status in your dashboard" : "Veðurlýsing á stjórnborðinu þínu",
    "Detect location" : "Finna staðsetningu",
    "Set custom address" : "Setja sérsniðið heimilisfang",
    "Favorites" : "Eftirlæti",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} heiðskírt seinnipartinn",
    "{temperature} {unit} clear sky" : "{temperature} {unit} heiðskírt",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} skýjað seinnipartinn",
    "{temperature} {unit} cloudy" : "{temperature} {unit} skýjað",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} bjartviðri seinnipartinn",
    "{temperature} {unit} fair weather" : "{temperature} {unit} bjartviðri",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} hálfskýjað seinnipartinn",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} hálfskýjað",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} þoka seinnipartinn",
    "{temperature} {unit} foggy" : "{temperature} {unit} þoka",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} dálítil rigning seinnipartinn",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} dálítil rigning",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} rigning seinnipartinn",
    "{temperature} {unit} rainfall" : "{temperature} {unit} rigning",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} talsverð rigning seinnipartinn",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} talsverð rigning",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} skúrir seinnipartinn",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} skúrir",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} dálitlir skúrir seinnipartinn",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} dálitlir skúrir",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} talsverðir skúrir seinnipartinn",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} talsverðir skúrir",
    "More weather for {adr}" : "Nánari veðurgögn fyrir {adr}",
    "Loading weather" : "Hleð inn veðurlýsingu",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add as favorite" : "Bæta við sem eftirlæti",
    "You are not logged in." : "Þú ert ekki skráð/ur inn.",
    "There was an error getting the weather status information." : "Villa kom upp við að ná í veðurupplýsingar.",
    "No weather information found" : "Engar veðurupplýsingar fundust",
    "Location not found" : "Staðsetningin fannst ekki",
    "There was an error setting the location address." : "Það kom upp villa við að stilla staðinn.",
    "There was an error setting the location." : "Það kom upp villa við að stilla staðsetninguna.",
    "There was an error saving the mode." : "Það kom upp villa við að vista haminn.",
    "There was an error using personal address." : "Það kom upp villa við að nota persónulegt heimilisfang.",
    "Set location for weather" : "Stilla staðsetningu fyrir veður",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Veðurupplýsingar innfelldar í stjórnborðsforritið.\n    Hægt er að ákvarða staðsetningu notanda sjálfvirkt eða handvirkt. Þá verður 6 klukkustunda veðurspá birt.\n    Þessar upplýsingar má einnig samtvinna á öðrum stöðum eins og í dagatalsforritinu."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/weather_status/l10n/is.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Óþekkt vistfang",
    "No result." : "Engar niðurstöður.",
    "Malformed JSON data." : "Gölluð JSON-gögn.",
    "Error" : "Villa",
    "Weather status" : "Veðurlýsing",
    "Weather status in your dashboard" : "Veðurlýsing á stjórnborðinu þínu",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Veðurupplýsingar innfelldar í stjórnborðsforritið.\n    Hægt er að ákvarða staðsetningu sjálfvirkt eða handvirkt. Þá verður 6 klukkustunda veðurspá birt.\n    Þessar upplýsingar má einnig samtvinna á öðrum stöðum eins og í dagatalsforritinu.",
    "Detect location" : "Finna staðsetningu",
    "Set custom address" : "Setja sérsniðið heimilisfang",
    "Favorites" : "Eftirlæti",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} heiðskírt seinnipartinn",
    "{temperature} {unit} clear sky" : "{temperature} {unit} heiðskírt",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} skýjað seinnipartinn",
    "{temperature} {unit} cloudy" : "{temperature} {unit} skýjað",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} snjókoma og þrumuveður seinnipartinn",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} snjókoma og þrumuveður",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} snjóél og þrumuveður seinnipartinn",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} snjóél og þrumuveður",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} snjóél, þrumuveður og dimmt seinnipartinn",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} snjóél, þrumuveður og dimmt",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} snjóél seinnipartinn",
    "{temperature} {unit} snow showers" : "{temperature} {unit} snjóél",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} snjóél og dimmt seinnipartinn",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} snjóél og dimmt",
    "{temperature} {unit} snow later today" : "{temperature} {unit} snjókoma seinnipartinn",
    "{temperature} {unit} snow" : "{temperature} {unit} snjókpma",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} bjartviðri seinnipartinn",
    "{temperature} {unit} fair weather" : "{temperature} {unit} bjartviðri",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} hálfskýjað seinnipartinn",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} hálfskýjað",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} þoka seinnipartinn",
    "{temperature} {unit} foggy" : "{temperature} {unit} þoka",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} dálítil rigning seinnipartinn",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} dálítil rigning",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} rigning seinnipartinn",
    "{temperature} {unit} rainfall" : "{temperature} {unit} rigning",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} talsverð rigning seinnipartinn",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} talsverð rigning",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} skúrir seinnipartinn",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} skúrir",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} dálitlir skúrir seinnipartinn",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} dálitlir skúrir",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} talsverðir skúrir seinnipartinn",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} talsverðir skúrir",
    "More weather for {adr}" : "Nánari veðurgögn fyrir {adr}",
    "Loading weather" : "Hleð inn veðurlýsingu",
    "Set location for weather" : "Stilla staðsetningu fyrir veður",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add as favorite" : "Bæta við sem eftirlæti",
    "You are not logged in." : "Þú ert ekki skráð/ur inn.",
    "There was an error getting the weather status information." : "Villa kom upp við að ná í veðurupplýsingar.",
    "No weather information found" : "Engar veðurupplýsingar fundust",
    "Location not found" : "Staðsetningin fannst ekki",
    "There was an error setting the location address." : "Það kom upp villa við að stilla staðinn.",
    "There was an error setting the location." : "Það kom upp villa við að stilla staðsetninguna.",
    "There was an error saving the mode." : "Það kom upp villa við að vista haminn.",
    "There was an error using personal address." : "Það kom upp villa við að nota persónulegt heimilisfang.",
    "Unknown weather code" : "Óþekktur veðurkóði"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
